@@ -1,4 +1,4 @@
-from PySide2.QtGui import QColor
+from PySide6.QtGui import QColor
 
 class Setup:
     DB_PATH = "jal.sqlite"
@@ -11,7 +11,7 @@ class Setup:
     IMPORT_SCHEMA_NAME = "import_schema.json"
     LANG_PATH = "languages"
     UPDATE_PREFIX = 'jal_delta_'
-    TARGET_SCHEMA = 27
+    TARGET_SCHEMA = 28
     CALC_TOLERANCE = 1e-10
     DISP_TOLERANCE = 1e-4
 
@@ -61,7 +61,7 @@ class CorporateAction:   # CORPORATE ACTIONS FOR ASSETS
 
 
 class PredefindedAccountType:
-    Case = 1
+    Cash = 1
     Bank = 2
     Card = 3
     Investment = 4
