@@ -1,17 +1,16 @@
 import decimal
 from datetime import datetime
 
-from PySide2.QtCore import Qt, Slot, QAbstractItemModel, QDate, QModelIndex, QLocale
-from PySide2.QtGui import QBrush, QFont
-from PySide2.QtWidgets import QHeaderView
+from PySide6.QtCore import Qt, Slot, QAbstractItemModel, QDate, QModelIndex, QLocale
+from PySide6.QtGui import QBrush, QFont
+from PySide6.QtWidgets import QHeaderView
 from jal.constants import Setup, CustomColor, BookAccount, PredefindedAccountType
 from jal.db.helpers import executeSQL, readSQLrecord
-from jal.db.update import JalDB
-from jal.widgets.helpers import g_tr
+from jal.db.db import JalDB
 from jal.widgets.delegates import GridLinesDelegate
 
 
-class TreeItem():
+class TreeItem:
     def __init__(self, data, parent=None):
         self._parent = parent
         self.data = data.copy()
@@ -46,16 +45,16 @@ class HoldingsModel(QAbstractItemModel):
         self._currency_name = ''
         self._date = QDate.currentDate().endOfDay(Qt.UTC).toSecsSinceEpoch()
         self.calculated_names = ['share', 'profit', 'profit_rel', 'value', 'value_a']
-        self._columns = [g_tr('HoldingsModel', "Currency/Account/Asset"),
-                         g_tr('HoldingsModel', "Asset Name"),
-                         g_tr('HoldingsModel', "Qty"),
-                         g_tr('HoldingsModel', "Open"),
-                         g_tr('HoldingsModel', "Last"),
-                         g_tr('HoldingsModel', "Share, %"),
-                         g_tr('HoldingsModel', "P/L, %"),
-                         g_tr('HoldingsModel', "P/L"),
-                         g_tr('HoldingsModel', "Value"),
-                         g_tr('HoldingsModel', "Value, ")]
+        self._columns = [self.tr("Currency/Account/Asset"),
+                         self.tr("Asset Name"),
+                         self.tr("Qty"),
+                         self.tr("Open"),
+                         self.tr("Last"),
+                         self.tr("Share, %"),
+                         self.tr("P/L, %"),
+                         self.tr("P/L"),
+                         self.tr("Value"),
+                         self.tr("Value, ")]
 
     def rowCount(self, parent=None):
         if not parent.isValid():
@@ -105,7 +104,7 @@ class HoldingsModel(QAbstractItemModel):
         if role == Qt.FontRole:
             return self.data_font(item.data, index.column())
         if role == Qt.BackgroundRole:
-            return self.data_background(item.data, index.column())
+            return self.data_background(item.data, index.column(), self._view.isEnabled())
         if role == Qt.TextAlignmentRole:
             if index.column() < 2:
                 return Qt.AlignLeft
@@ -125,7 +124,7 @@ class HoldingsModel(QAbstractItemModel):
             expiry_text = ""
             if data['expiry']:
                 expiry_date = datetime.utcfromtimestamp(data['expiry'])
-                expiry_header = g_tr('HoldingsModel', "Exp:")
+                expiry_header = self.tr("Exp:")
                 expiry_text = f" [{expiry_header} {expiry_date.strftime('%d.%m.%Y')}]"
             return data['asset_name'] + expiry_text
         elif column == 2:
@@ -175,21 +174,22 @@ class HoldingsModel(QAbstractItemModel):
                         font.setItalic(True)
                     return font
 
-    def data_background(self, data, column):
+    def data_background(self, data, column, enabled=True):
+        factor = 100 if enabled else 125
         if data['level'] == 0:
-            return QBrush(CustomColor.LightPurple)
+            return QBrush(CustomColor.LightPurple.lighter(factor))
         if data['level'] == 1:
-            return QBrush(CustomColor.LightBlue)
+            return QBrush(CustomColor.LightBlue.lighter(factor))
         if column == 6 and data['profit_rel']:
             if data['profit_rel'] >= 0:
-                return QBrush(CustomColor.LightGreen)
+                return QBrush(CustomColor.LightGreen.lighter(factor))
             else:
-                return QBrush(CustomColor.LightRed)
+                return QBrush(CustomColor.LightRed.lighter(factor))
         if column == 7 and data['profit']:
             if data['profit'] >= 0:
-                return QBrush(CustomColor.LightGreen)
+                return QBrush(CustomColor.LightGreen.lighter(factor))
             else:
-                return QBrush(CustomColor.LightRed)
+                return QBrush(CustomColor.LightRed.lighter(factor))
 
     def configureView(self):
         self._view.header().setSectionResizeMode(0, QHeaderView.ResizeToContents)
