@@ -1,13 +1,12 @@
 import logging
 from datetime import datetime
 from math import copysign
-from PySide2.QtCore import Signal, QObject, QDate
-from PySide2.QtWidgets import QDialog, QMessageBox
+from PySide6.QtCore import Signal, QObject, QDate
+from PySide6.QtWidgets import QDialog, QMessageBox
 from jal.constants import Setup, BookAccount, TransactionType, TransferSubtype, ActionSubtype, DividendSubtype, \
     CorporateAction, PredefinedCategory, PredefinedPeer
 from jal.db.helpers import executeSQL, readSQL, readSQLrecord, db_triggers_disable, db_triggers_enable
-from jal.db.update import JalDB
-from jal.widgets.helpers import g_tr
+from jal.db.db import JalDB
 from jal.ui.ui_rebuild_window import Ui_ReBuildDialog
 
 
@@ -39,15 +38,49 @@ class RebuildDialog(QDialog, Ui_ReBuildDialog):
             return 0
 
 
+# ===================================================================================================================
+# Subclasses dictionary to store last amount/value for [book, account, asset]
+# Differs from dictionary in a way that __getitem__() method uses DB-stored values for initialization
+class LedgerAmounts(dict):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    def __getitem__(self, key):
+        # predefined indices in key tuple
+        BOOK = 0
+        ACCOUNT = 1
+        ASSET = 2
+
+        try:
+            return super().__getitem__(key)
+        except KeyError:
+            amount = readSQL("SELECT sum_amount FROM ledger_sums "
+                             "WHERE book_account = :book AND account_id = :account_id AND asset_id = :asset_id "
+                             "ORDER BY sid DESC LIMIT 1",
+                             [(":book", key[BOOK]), (":account_id", key[ACCOUNT]), (":asset_id", key[ASSET])])
+            amount = float(amount) if amount is not None else 0.0
+            super().__setitem__(key, amount)
+            return amount
+
+
 # ===================================================================================================================
 class Ledger(QObject):
     updated = Signal()
-    SILENT_REBUILD_THRESHOLD = 50
+    SILENT_REBUILD_THRESHOLD = 1000
 
     def __init__(self):
         QObject.__init__(self)
         self.current = {}
         self.current_seq = -1
+        self.amounts = LedgerAmounts()    # store last amount for [book, account, asset]
+        self.values = LedgerAmounts()     # together with corresponding value
+        self.sids = {}                    # and keep sid of operation that modified it
+        self.main_window =None
+        self.progress_bar = None
+
+    def setProgressBar(self, main_window, progress_widget):
+        self.main_window = main_window
+        self.progress_bar = progress_widget
 
     # Returns timestamp of last operations that were calculated into ledger
     def getCurrentFrontier(self):
@@ -76,23 +109,10 @@ class Ledger(QObject):
             peer_id = None
             category_id = None
             tag_id = None
-        try:
-            old_sid, old_amount, old_value = readSQL(
-                "SELECT sid, sum_amount, sum_value FROM ledger_sums "
-                "WHERE book_account = :book AND asset_id = :asset_id "
-                "AND account_id = :account_id AND sid <= :seq_id "
-                "ORDER BY sid DESC LIMIT 1",
-                [(":book", book), (":asset_id", asset_id), (":account_id", account_id), (":seq_id", seq_id)])
-        except:
-            old_sid = -1
-            old_amount = 0.0
-            old_value = 0.0
-        new_amount = old_amount + amount
-        if value is None:
-            new_value = old_value
-        else:
-            new_value = old_value + value
-        if (abs(new_amount - old_amount) + abs(new_value - old_value)) <= (2 * Setup.CALC_TOLERANCE):
+        value = 0.0 if value is None else value
+        self.amounts[(book, account_id, asset_id)] += amount
+        self.values[(book, account_id, asset_id)] += value
+        if (abs(amount) + abs(value)) <= (4 * Setup.CALC_TOLERANCE):
             return  # we have zero amount - no reason to put it into ledger
 
         _ = executeSQL("INSERT INTO ledger (timestamp, sid, book_account, asset_id, account_id, "
@@ -102,11 +122,16 @@ class Ledger(QObject):
                        [(":timestamp", timestamp), (":sid", seq_id), (":book", book), (":asset_id", asset_id),
                         (":account_id", account_id), (":amount", amount), (":value", value),
                         (":peer_id", peer_id), (":category_id", category_id), (":tag_id", tag_id)])
+        try:
+            old_sid = self.sids[(book, account_id, asset_id)]
+        except KeyError:
+            old_sid = -1
         if seq_id == old_sid:
             _ = executeSQL("UPDATE ledger_sums SET sum_amount = :new_amount, sum_value = :new_value"
                            " WHERE sid = :sid AND book_account = :book"
                            " AND asset_id = :asset_id AND account_id = :account_id",
-                           [(":new_amount", new_amount), (":new_value", new_value), (":sid", seq_id),
+                           [(":new_amount", self.amounts[(book, account_id, asset_id)]),
+                            (":new_value", self.values[(book, account_id, asset_id)]), (":sid", seq_id),
                             (":book", book), (":asset_id", asset_id), (":account_id", account_id)], commit=True)
         else:
             _ = executeSQL("INSERT INTO ledger_sums(sid, timestamp, book_account, "
@@ -114,25 +139,16 @@ class Ledger(QObject):
                            "VALUES(:sid, :timestamp, :book, :asset_id, "
                            ":account_id, :new_amount, :new_value)",
                            [(":sid", seq_id), (":timestamp", timestamp), (":book", book), (":asset_id", asset_id),
-                            (":account_id", account_id), (":new_amount", new_amount), (":new_value", new_value)],
+                            (":account_id", account_id), (":new_amount", self.amounts[(book, account_id, asset_id)]),
+                            (":new_value", self.values[(book, account_id, asset_id)])],
                            commit=True)
+            self.sids[(book, account_id, asset_id)] = seq_id
 
-    # TODO check that condition <= is really correct for timestamp in this function
-    # Returns Amount measured in current account currency or asset_id that 'book' has at current ledger frontier
+    # Returns Amount measured in current account currency or asset that 'book' has at current ledger frontier
     def getAmount(self, book, asset_id=None):
         if asset_id is None:
-            amount = readSQL("SELECT sum_amount FROM ledger_sums WHERE book_account = :book AND "
-                             "account_id = :account_id AND timestamp <= :timestamp ORDER BY sid DESC LIMIT 1",
-                             [(":book", book), (":account_id", self.current['account']),
-                              (":timestamp", self.current['timestamp'])])
-        else:
-            amount = readSQL("SELECT sum_amount FROM ledger_sums WHERE book_account = :book "
-                             "AND account_id = :account_id AND asset_id = :asset_id "
-                             "AND timestamp <= :timestamp ORDER BY sid DESC LIMIT 1",
-                             [(":book", book), (":account_id", self.current['account']),
-                              (":asset_id", asset_id), (":timestamp", self.current['timestamp'])])
-        amount = float(amount) if amount is not None else 0.0
-        return amount
+            asset_id = self.current['currency']
+        return self.amounts[(book, self.current['account'], asset_id)]
 
     def takeCredit(self, operation_amount):
         money_available = self.getAmount(BookAccount.Money)
@@ -164,7 +180,7 @@ class Ledger(QObject):
 
     def processAction(self):
         if self.current['amount'] == '':
-            logging.warning(g_tr('Ledger', "Can't process operation without details") +
+            logging.warning(self.tr("Can't process operation without details") +
                             f" @{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d.%m.%Y %H:%M:%S')}")
             return
         action_amount = self.current['amount']
@@ -188,10 +204,10 @@ class Ledger(QObject):
         elif self.current['subtype'] == DividendSubtype.BondInterest:
             self.current['category'] = PredefinedCategory.Interest
         else:
-            logging.error(g_tr('Ledger', "Can't process dividend with N/A type"))
+            logging.error(self.tr("Can't process dividend with N/A type"))
             return
         if self.current['peer'] == '':
-            logging.error(g_tr('Ledger', "Can't process dividend as bank isn't set for investment account"))
+            logging.error(self.tr("Can't process dividend as bank isn't set for investment account"))
             return
         dividend_amount = self.current['amount']
         tax_amount = self.current['fee_tax']
@@ -213,7 +229,7 @@ class Ledger(QObject):
     # Process buy or sell operation base on self.current['amount'] (>0 - buy, <0 - sell)
     def processTrade(self):
         if self.current['peer'] == '':
-            logging.error(g_tr('Ledger', "Can't process trade as bank isn't set for investment account"))
+            logging.error(self.tr("Can't process trade as bank isn't set for investment account"))
             return
 
         seq_id = self.current_seq
@@ -363,7 +379,7 @@ class Ledger(QObject):
                 self.appendTransaction(BookAccount.Money, (self.current['amount'] - credit_returned))
             self.appendTransaction(BookAccount.Transfers, -self.current['amount'])
         else:   # TODO implement assets transfer
-            logging.error(g_tr('Ledger', "Unexpected data in transfer transaction"))
+            logging.error(self.tr("Unexpected data in transfer transaction"))
             return
 
     def updateStockDividendAssets(self):
@@ -371,10 +387,10 @@ class Ledger(QObject):
         self.current['price'] = self.current['price'] + asset_amount
         self.current['amount'] = asset_amount
         asset = JalDB().get_asset_name(self.current['asset'])
-        QMessageBox().information(None, g_tr('Ledger', "Confirmation"),
-                                  g_tr('Ledger', "Stock dividend for was updated for ") + asset +
+        QMessageBox().information(None, self.tr("Confirmation"),
+                                  self.tr("Stock dividend for was updated for ") + asset +
                                   f" @{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d.%m.%Y')}\n" +
-                                  g_tr('Ledger', "Please check that quantity is correct."),
+                                  self.tr("Please check that quantity is correct."),
                                   QMessageBox.Ok)
         _ = executeSQL("UPDATE corp_actions SET qty=:qty, qty_new=:qty_new WHERE id=:id",
                        [(":id", self.current['id']),
@@ -395,7 +411,7 @@ class Ledger(QObject):
         # Get asset amount accumulated before current operation
         asset_amount = self.getAmount(BookAccount.Assets, asset_id)
         if asset_amount < (qty - 2*Setup.CALC_TOLERANCE):
-            logging.fatal(g_tr('Ledger', "Asset amount is not enough for corporate action processing. Date: ")
+            logging.fatal(self.tr("Asset amount is not enough for corporate action processing. Date: ")
                           + f"{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d/%m/%Y %H:%M:%S')}")
             return
         # Get information about last deal
@@ -493,7 +509,7 @@ class Ledger(QObject):
     #      will asks for confirmation if we have more than SILENT_REBUILD_THRESHOLD operations require rebuild
     # 0 - re-build from scratch
     # any - re-build all operations after given timestamp
-    def rebuild(self, from_timestamp=-1, fast_and_dirty=False, silent=True):
+    def rebuild(self, from_timestamp=-1, fast_and_dirty=False):
         operationProcess = {
             TransactionType.Action: self.processAction,
             TransactionType.Dividend: self.processDividend,
@@ -502,22 +518,28 @@ class Ledger(QObject):
             TransactionType.CorporateAction: self.processCorporateAction
         }
 
+        # Initialize arrays for rolling sums storage
+        self.amounts = LedgerAmounts()
+        self.values = LedgerAmounts()
+        self.sids = {}
         if from_timestamp >= 0:
             frontier = from_timestamp
-            silent = False
+            operations_count = readSQL("SELECT COUNT(id) FROM all_transactions WHERE timestamp >= :frontier",
+                                       [(":frontier", frontier)])
         else:
             frontier = self.getCurrentFrontier()
             operations_count = readSQL("SELECT COUNT(id) FROM all_transactions WHERE timestamp >= :frontier",
                                        [(":frontier", frontier)])
             if operations_count > self.SILENT_REBUILD_THRESHOLD:
-                silent = False
-                if QMessageBox().warning(None, g_tr('Ledger', "Confirmation"), f"{operations_count}" +
-                                         g_tr('Ledger', " operations require rebuild. Do you want to do it right now?"),
+                if QMessageBox().warning(None, self.tr("Confirmation"), f"{operations_count}" +
+                                         self.tr(" operations require rebuild. Do you want to do it right now?"),
                                          QMessageBox.Yes, QMessageBox.No) == QMessageBox.No:
                     return
-        if not silent:
-            logging.info(g_tr('Ledger', "Re-build ledger from: ") +
-                         f"{datetime.utcfromtimestamp(frontier).strftime('%d/%m/%Y %H:%M:%S')}")
+        if self.progress_bar is not None:
+            self.progress_bar.setRange(0, operations_count)
+            self.main_window.showProgressBar(True)
+        logging.info(self.tr("Re-building ledger since: ") +
+                     f"{datetime.utcfromtimestamp(frontier).strftime('%d/%m/%Y %H:%M:%S')}")
         start_time = datetime.now()
         _ = executeSQL("DELETE FROM deals WHERE close_sid >= "
                        "(SELECT coalesce(MIN(id), 0) FROM sequence WHERE timestamp >= :frontier)",
@@ -545,36 +567,22 @@ class Ledger(QObject):
                                         (":subtype", subtype), (":operation_id", self.current['id'])])
                 self.current_seq = seq_query.lastInsertId()
                 operationProcess[self.current['type']]()
-                if not silent and (query.at() % 1000) == 0:
-                    logging.info(
-                        g_tr('Ledger', "Processed ") + f"{int(query.at()/1000)}" +
-                        g_tr('Ledger', "k records, current frontier: ") +
-                        f"{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d/%m/%Y %H:%M:%S')}")
+                if self.progress_bar is not None:
+                    self.progress_bar.setValue(query.at())
         finally:
             if fast_and_dirty:
                 _ = executeSQL("PRAGMA synchronous = ON")
             db_triggers_enable()
 
-        if not silent:
-            logging.info(g_tr('Ledger', "Ledger is complete. Elapsed time: ") + f"{datetime.now() - start_time}" +
-                         g_tr('Ledger', ", new frontier: ") + f"{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d/%m/%Y %H:%M:%S')}")
+        if self.progress_bar is not None:
+            self.main_window.showProgressBar(False)
+        logging.info(self.tr("Ledger is complete. Elapsed time: ") + f"{datetime.now() - start_time}" +
+                     self.tr(", new frontier: ") + f"{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d/%m/%Y %H:%M:%S')}")
 
         self.updated.emit()
 
     def showRebuildDialog(self, parent):
         rebuild_dialog = RebuildDialog(parent, self.getCurrentFrontier())
-        if rebuild_dialog.exec_():
+        if rebuild_dialog.exec():
             self.rebuild(from_timestamp=rebuild_dialog.getTimestamp(),
-                         fast_and_dirty=rebuild_dialog.isFastAndDirty(), silent=False)
-
-    def get_asset_amount(self, timestamp, account_id, asset_id):
-        return readSQL("SELECT sum_amount FROM ledger_sums "
-                       "WHERE account_id=:account_id AND asset_id=:asset_id AND timestamp<=:timestamp "
-                       "AND (book_account=:money OR book_account=:assets)"
-                       "ORDER BY sid DESC LIMIT 1",
-                       [(":account_id", account_id), (":asset_id", asset_id), (":timestamp", timestamp),
-                        (":money", BookAccount.Money), (":assets", BookAccount.Assets)])
-
-    def reconcile(self, account_id, timestamp):
-        _ = executeSQL("UPDATE accounts SET reconciled_on=:timestamp WHERE id = :account_id",
-                       [(":timestamp", timestamp), (":account_id", account_id)])
+                         fast_and_dirty=rebuild_dialog.isFastAndDirty())
