@@ -6,16 +6,14 @@ from io import StringIO
 import pandas as pd
 from pandas.errors import ParserError
 import json
-from PySide2 import QtCore
-from PySide2.QtCore import QObject, Signal
-from PySide2.QtWidgets import QDialog
+from PySide6.QtCore import QObject, Signal, QDate
+from PySide6.QtWidgets import QApplication, QDialog
 
 from jal.ui.ui_update_quotes_window import Ui_UpdateQuotesDlg
 from jal.constants import Setup, MarketDataFeed, BookAccount, PredefinedAsset
 from jal.db.helpers import executeSQL, readSQLrecord
-from jal.db.update import JalDB
+from jal.db.db import JalDB
 from jal.net.helpers import get_web_data, post_web_data, isEnglish
-from jal.widgets.helpers import g_tr
 
 
 # ===================================================================================================================
@@ -25,12 +23,12 @@ class QuotesUpdateDialog(QDialog, Ui_UpdateQuotesDlg):
     def __init__(self, parent):
         QDialog.__init__(self, parent=parent)
         self.setupUi(self)
-        self.StartDateEdit.setDate(QtCore.QDate.currentDate().addMonths(-1))
-        self.EndDateEdit.setDate(QtCore.QDate.currentDate())
+        self.StartDateEdit.setDate(QDate.currentDate().addMonths(-1))
+        self.EndDateEdit.setDate(QDate.currentDate())
 
         # center dialog with respect to parent window
-        x = parent.x() + parent.width()/2 - self.width()/2
-        y = parent.y() + parent.height()/2 - self.height()/2
+        x = parent.x() + parent.width() / 2 - self.width() / 2
+        y = parent.y() + parent.height() / 2 - self.height() / 2
         self.setGeometry(x, y, self.width(), self.height())
 
     def getStartDate(self):
@@ -61,14 +59,13 @@ class QuoteDownloader(QObject):
 
     def showQuoteDownloadDialog(self, parent):
         dialog = QuotesUpdateDialog(parent)
-        if dialog.exec_():
+        if dialog.exec():
             self.UpdateQuotes(dialog.getStartDate(), dialog.getEndDate())
             self.download_completed.emit()
 
     def UpdateQuotes(self, start_timestamp, end_timestamp):
         self.PrepareRussianCBReader()
         jal_db = JalDB()
-
         query = executeSQL("WITH _holdings AS ( "
                            "SELECT l.asset_id AS asset FROM ledger AS l "
                            "WHERE l.book_account = 4 AND l.timestamp <= :end_timestamp "
@@ -108,13 +105,13 @@ class QuoteDownloader(QObject):
                 data = self.data_loaders[asset['feed_id']](asset['asset_id'], asset['name'], asset['isin'],
                                                            from_timestamp, end_timestamp)
             except (xml_tree.ParseError, pd.errors.EmptyDataError, KeyError):
-                logging.warning(g_tr('QuotesUpdateDialog', "No data were downloaded for ") + f"{asset}")
+                logging.warning(self.tr("No data were downloaded for ") + f"{asset}")
                 continue
             if data is not None:
                 for date, quote in data.iterrows():  # Date in pandas dataset is in UTC by default
                     jal_db.update_quote(asset['asset_id'], int(date.timestamp()), float(quote[0]))
         jal_db.commit()
-        logging.info(g_tr('QuotesUpdateDialog', "Download completed"))
+        logging.info(self.tr("Download completed"))
 
     def PrepareRussianCBReader(self):
         rows = []
@@ -168,9 +165,9 @@ class QuoteDownloader(QObject):
             data = QuoteDownloader.MOEX_download_info(kwargs['isin'])
         # If not found try to use search API with regnumber or isin
         if not data and 'regnumber' in kwargs:
-            data = QuoteDownloader.MOEX_download_info(QuoteDownloader.MOEX_find_secid_by_regcode(kwargs['regnumber']))
+            data = QuoteDownloader.MOEX_download_info(QuoteDownloader.MOEX_find_secid(regcode=kwargs['regnumber']))
         if not data and 'isin' in kwargs:
-            data = QuoteDownloader.MOEX_download_info(QuoteDownloader.MOEX_find_secid_by_regcode(kwargs['isin']))
+            data = QuoteDownloader.MOEX_download_info(QuoteDownloader.MOEX_find_secid(isin=kwargs['isin']))
         if 'special' not in kwargs:
             for key in ['engine', 'market', 'board']:
                 try:
@@ -228,7 +225,7 @@ class QuoteDownloader(QObject):
         try:
             asset['type'] = asset_type[asset['type']]
         except KeyError:
-            logging.error(g_tr('QuoteDownloader', "Unsupported MOEX security type: ") + f"{asset['type']}")
+            logging.error(QApplication.translate("MOEX", "Unsupported MOEX security type: ") + f"{asset['type']}")
             return {}
 
         for board in boards:
@@ -239,21 +236,33 @@ class QuoteDownloader(QObject):
                 break
         return asset
 
-    # Searches for asset info on http://www.moex.com by given reg.number
-    # Returns ISIN if asset was found and empty string otherwise
+    # Searches for asset info on http://www.moex.com by given reg.number or isin
+    # Returns 'secid' if asset was found and empty string otherwise
     @staticmethod
-    def MOEX_find_secid_by_regcode(regnumber) -> str:
+    def MOEX_find_secid(**kwargs) -> str:
         secid = ''
-        if not regnumber:
+        try:
+            search_key = kwargs['regcode'] if 'regcode' in kwargs else kwargs['isin']
+        except KeyError:
             return secid
-        url = f"https://iss.moex.com/iss/securities.json?q={regnumber}&iss.meta=off&limit=10"
+        if not search_key:
+            return secid
+        url = f"https://iss.moex.com/iss/securities.json?q={search_key}&iss.meta=off&limit=10"
         asset_data = json.loads(get_web_data(url))
         securities = asset_data['securities']
         columns = securities['columns']
-        data = securities['data']
+        if 'regcode' in kwargs:
+            # Take only records that have given regnumber to get rid of additional issues
+            data = [x for x in securities['data'] if
+                    x[columns.index('regnumber')] == search_key or x[columns.index('regnumber')] is None]
+        else:
+            data = securities['data']  # take the whole list if we search by isin
         if data:
             if len(data) > 1:
-                logging.info(g_tr('QuoteDownloader', "MOEX: multiple assets found for reg.number: ") + regnumber)
+                # remove not traded assets if there are any outdated doubles present
+                data = [x for x in data if x[columns.index('is_traded')] == 1]
+            if len(data) > 1:  # and then check again
+                logging.info(QApplication.translate("MOEX", "Multiple MOEX assets found for reg.number: ") + search_key)
                 return secid
             asset_data = dict(zip(columns, data[0]))
             secid = asset_data['secid'] if 'secid' in asset_data else ''
@@ -265,6 +274,8 @@ class QuoteDownloader(QObject):
         if (asset['engine'] is None) or (asset['market'] is None) or (asset['board'] is None):
             logging.warning(f"Failed to find {asset_code} on moex.com")
             return None
+        if (asset['market'] == 'bonds') and (asset['board'] == 'TQCB'):
+            asset_code = isin   # Corporate bonds are quoted by ISIN
 
         isin = asset['isin'] if 'isin' in asset else ''
         reg_code = asset['reg_code'] if 'reg_code' in asset else ''
@@ -274,7 +285,7 @@ class QuoteDownloader(QObject):
         # Get price history
         date1 = datetime.utcfromtimestamp(start_timestamp).strftime('%Y-%m-%d')
         date2 = datetime.utcfromtimestamp(end_timestamp).strftime('%Y-%m-%d')
-        url = f"http://iss.moex.com/iss/history/engines/{asset['engine']}/markets/{asset['market']}/"\
+        url = f"http://iss.moex.com/iss/history/engines/{asset['engine']}/markets/{asset['market']}/" \
               f"boards/{asset['board']}/securities/{asset_code}.xml?from={date1}&till={date2}"
         xml_root = xml_tree.fromstring(get_web_data(url))
         history_rows = xml_root.findall("data[@id='history']/rows/*")
@@ -294,7 +305,7 @@ class QuoteDownloader(QObject):
 
     # noinspection PyMethodMayBeStatic
     def Yahoo_Downloader(self, _asset_id, asset_code, _isin, start_timestamp, end_timestamp):
-        url = f"https://query1.finance.yahoo.com/v7/finance/download/{asset_code}?"\
+        url = f"https://query1.finance.yahoo.com/v7/finance/download/{asset_code}?" \
               f"period1={start_timestamp}&period2={end_timestamp}&interval=1d&events=history"
         file = StringIO(get_web_data(url))
         try:
@@ -315,13 +326,13 @@ class QuoteDownloader(QObject):
         quotes = post_web_data(url, params=params)
         quotes_text = quotes.splitlines()
         if len(quotes_text) < 4:
-            logging.warning(g_tr('QuotesUpdateDialog', "Euronext quotes history reply is too short: ") + quotes)
+            logging.warning(self.tr("Euronext quotes history reply is too short: ") + quotes)
             return None
         if quotes_text[0] != '"Historical Data"':
-            logging.warning(g_tr('QuotesUpdateDialog', "Euronext quotes header not found in: ") + quotes)
+            logging.warning(self.tr("Euronext quotes header not found in: ") + quotes)
             return None
         if quotes_text[2] != isin:
-            logging.warning(g_tr('QuotesUpdateDialog', "Euronext quotes ISIN mismatch in: ") + quotes)
+            logging.warning(self.tr("Euronext quotes ISIN mismatch in: ") + quotes)
             return None
         file = StringIO(quotes)
         try:
@@ -358,7 +369,7 @@ class QuoteDownloader(QObject):
         if 'getCompanyPriceHistoryForDownload' in result_data:
             price_array = result_data['getCompanyPriceHistoryForDownload']
         else:
-            logging.warning(g_tr('QuotesUpdateDialog', "Can't parse data for TSX quotes: ") + json_content)
+            logging.warning(self.tr("Can't parse data for TSX quotes: ") + json_content)
             return None
         data = pd.DataFrame(price_array)
         data.rename(columns={'datetime': 'Date', 'closePrice': 'Close'}, inplace=True)
