@@ -2,11 +2,10 @@ import logging
 from datetime import datetime
 from dateutil import tz
 
-from PySide2.QtCore import Qt, Slot
-from PySide2.QtWidgets import QLabel, QDateTimeEdit, QPushButton, QTableView, QHeaderView
-from PySide2.QtGui import QFont
-from PySide2.QtSql import QSqlTableModel
-from jal.widgets.helpers import g_tr
+from PySide6.QtCore import Qt, Slot
+from PySide6.QtWidgets import QLabel, QDateTimeEdit, QPushButton, QTableView, QHeaderView
+from PySide6.QtGui import QFont
+from PySide6.QtSql import QSqlTableModel
 from jal.widgets.abstract_operation_details import AbstractOperationDetails
 from jal.widgets.reference_selector import AccountSelector, PeerSelector
 from jal.widgets.account_select import OptionalCurrencyComboBox
@@ -37,27 +36,27 @@ class IncomeSpendingWidget(AbstractOperationDetails):
         self.account_label = QLabel(self)
         self.peer_label = QLabel(self)
 
-        self.main_label.setText(g_tr("IncomeSpendingWidget", "Income / Spending"))
-        self.date_label.setText(g_tr("IncomeSpendingWidget", "Date/Time"))
-        self.details_label.setText(g_tr("IncomeSpendingWidget", "Details"))
-        self.account_label.setText(g_tr("IncomeSpendingWidget", "Account"))
-        self.peer_label.setText(g_tr("IncomeSpendingWidget", "Peer"))
+        self.main_label.setText(self.tr("Income / Spending"))
+        self.date_label.setText(self.tr("Date/Time"))
+        self.details_label.setText(self.tr("Details"))
+        self.account_label.setText(self.tr("Account"))
+        self.peer_label.setText(self.tr("Peer"))
 
         self.timestamp_editor = QDateTimeEdit(self)
         self.timestamp_editor.setCalendarPopup(True)
         self.timestamp_editor.setTimeSpec(Qt.UTC)
-        self.timestamp_editor.setFixedWidth(self.timestamp_editor.fontMetrics().width("00/00/0000 00:00:00") * 1.25)
+        self.timestamp_editor.setFixedWidth(self.timestamp_editor.fontMetrics().horizontalAdvance("00/00/0000 00:00:00") * 1.25)
         self.timestamp_editor.setDisplayFormat("dd/MM/yyyy hh:mm:ss")
         self.account_widget = AccountSelector(self)
         self.peer_widget = PeerSelector(self)
         self.a_currency = OptionalCurrencyComboBox(self)
-        self.a_currency.setText(g_tr("IncomeSpendingWidget", "Paid in foreign currency:"))
+        self.a_currency.setText(self.tr("Paid in foreign currency:"))
         self.add_button = QPushButton(load_icon("add.png"), '', self)
-        self.add_button.setToolTip(g_tr("IncomeSpendingWidget", "Add detail"))
+        self.add_button.setToolTip(self.tr("Add detail"))
         self.del_button = QPushButton(load_icon("remove.png"), '', self)
-        self.del_button.setToolTip(g_tr("IncomeSpendingWidget", "Remove detail"))
+        self.del_button.setToolTip(self.tr("Remove detail"))
         self.copy_button = QPushButton(load_icon("copy.png"), '', self)
-        self.copy_button.setToolTip(g_tr("IncomeSpendingWidget", "Copy detail"))
+        self.copy_button.setToolTip(self.tr("Copy detail"))
         self.details_table = QTableView(self)
         self.details_table.horizontalHeader().setFont(self.bold_font)
         self.details_table.setAlternatingRowColors(True)
@@ -92,6 +91,8 @@ class IncomeSpendingWidget(AbstractOperationDetails):
         self.del_button.clicked.connect(self.delChild)
 
         super()._init_db("actions")
+        self.model.beforeInsert.connect(self.before_record_insert)
+        self.model.beforeUpdate.connect(self.before_record_update)
         self.mapper.setItemDelegate(IncomeSpendingWidgetDelegate(self.mapper))
 
         self.details_model = DetailsModel(self.details_table, db_connection())
@@ -103,7 +104,7 @@ class IncomeSpendingWidget(AbstractOperationDetails):
         self.account_widget.changed.connect(self.mapper.submit)
         self.peer_widget.changed.connect(self.mapper.submit)
         self.a_currency.changed.connect(self.mapper.submit)
-        self.a_currency.updated.connect(self.details_model.setAltCurrency)
+        self.a_currency.name_updated.connect(self.details_model.setAltCurrency)
 
         self.mapper.addMapping(self.timestamp_editor, self.model.fieldIndex("timestamp"))
         self.mapper.addMapping(self.account_widget, self.model.fieldIndex("account_id"))
@@ -130,8 +131,7 @@ class IncomeSpendingWidget(AbstractOperationDetails):
         new_record.setValue("amount", 0)
         new_record.setValue("amount_alt", 0)
         if not self.details_model.insertRecord(-1, new_record):
-            logging.fatal(
-                g_tr('AbstractOperationDetails', "Failed to add new record: ") + self.details_model.lastError().text())
+            logging.fatal(self.tr("Failed to add new record: ") + self.details_model.lastError().text())
             return
 
     @Slot()
@@ -148,8 +148,7 @@ class IncomeSpendingWidget(AbstractOperationDetails):
         new_record.setValue("amount_alt", src_record.value("amount_alt"))
         new_record.setValue("note", src_record.value("note"))
         if not self.details_model.insertRecord(-1, new_record):
-            logging.fatal(
-                g_tr('AbstractOperationDetails', "Failed to add new record: ") + self.details_model.lastError().text())
+            logging.fatal(self.tr("Failed to add new record: ") + self.details_model.lastError().text())
             return
 
     @Slot()
@@ -162,8 +161,7 @@ class IncomeSpendingWidget(AbstractOperationDetails):
     @Slot()
     def saveChanges(self):
         if not self.model.submitAll():
-            logging.fatal(
-                g_tr('AbstractOperationDetails', "Operation submit failed: ") + self.model.lastError().text())
+            logging.fatal(self.tr("Operation submit failed: ") + self.model.lastError().text())
             return
         pid = self.model.data(self.model.index(0, self.model.fieldIndex("id")))
         if pid is None:  # we just have saved new action record and need last inserted id
@@ -171,14 +169,12 @@ class IncomeSpendingWidget(AbstractOperationDetails):
         for row in range(self.details_model.rowCount()):
             self.details_model.setData(self.details_model.index(row, self.details_model.fieldIndex("pid")), pid)
         if not self.details_model.submitAll():
-            logging.fatal(g_tr('AbstractOperationDetails', "Operation details submit failed: ")
-                          + self.details_model.lastError().text())
+            logging.fatal(self.tr("Operation details submit failed: ") + self.details_model.lastError().text())
             return
         self.modified = False
         self.commit_button.setEnabled(False)
         self.revert_button.setEnabled(False)
         self.dbUpdated.emit()
-        return
 
     @Slot()
     def revertChanges(self):
@@ -220,25 +216,27 @@ class IncomeSpendingWidget(AbstractOperationDetails):
         new_record.setValue("timestamp", int(datetime.now().replace(tzinfo=tz.tzutc()).timestamp()))
         return new_record
 
+    def before_record_insert(self, record):
+        if record.value("alt_currency_id") == 0:
+            record.setNull("alt_currency_id")
+
+    def before_record_update(self, _row, record):
+        self.before_record_insert(record)   # processing is the same as before insert
+
 
 class DetailsModel(QSqlTableModel):
     def __init__(self, parent_view, db):
-        self._columns = ["id",
-                         "pid",
-                         g_tr('DetailsModel', "Category"),
-                         g_tr('DetailsModel', "Tag"),
-                         g_tr('DetailsModel', "Amount"),
-                         g_tr('DetailsModel', "Amount"),
-                         g_tr('DetailsModel', "Note")]
         super().__init__(parent=parent_view, db=db)
+        self._columns = ["id", "pid", self.tr("Category"), self.tr("Tag"),
+                         self.tr("Amount"), self.tr("Amount"), self.tr("Note")]
         self.deleted = []
-        self.alt_currency = ''
+        self.alt_currency_name = ''
         self._view = parent_view
 
     def headerData(self, section, orientation, role=Qt.DisplayRole):
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             if section == 5:
-                return self._columns[section] + ', ' + self.alt_currency
+                return self._columns[section] + ', ' + self.alt_currency_name
             else:
                 return self._columns[section]
         return None
@@ -277,10 +275,10 @@ class DetailsModel(QSqlTableModel):
         self._view.horizontalHeader().setSectionResizeMode(6, QHeaderView.Stretch)
         self._view.horizontalHeader().moveSection(6, 0)
 
-    def setAltCurrency(self, currency):
-        if currency:
+    def setAltCurrency(self, currency_name):
+        if currency_name:
             self._view.setColumnHidden(5, False)
-            self.alt_currency = currency
+            self.alt_currency_name = currency_name
             self.headerDataChanged.emit(Qt.Horizontal, 5, 5)
         else:
             self._view.setColumnHidden(5, True)
