@@ -2,19 +2,19 @@ import os
 import logging
 from functools import partial
 
-from PySide2.QtCore import Qt, Slot, QDateTime, QDir, QLocale
-from PySide2.QtGui import QIcon
-from PySide2.QtWidgets import QApplication, QMainWindow, QMenu, QMessageBox, QLabel, QActionGroup, QAction
+from PySide6.QtCore import Qt, Slot, QDateTime, QDir, QLocale
+from PySide6.QtGui import QIcon, QActionGroup, QAction
+from PySide6.QtWidgets import QApplication, QMainWindow, QMenu, QMessageBox, QLabel, QProgressBar
 
 from jal import __version__
 from jal.ui.ui_main_window import Ui_JAL_MainWindow
-from jal.widgets.helpers import g_tr, ManipulateDate, dependency_present
+from jal.widgets.helpers import ManipulateDate, dependency_present
 from jal.widgets.reference_dialogs import AccountTypeListDialog, AccountListDialog, AssetListDialog, TagsListDialog,\
     CategoryListDialog, CountryListDialog, QuotesListDialog, PeerListDialog
 from jal.constants import Setup, TransactionType
 from jal.db.backup_restore import JalBackup
 from jal.db.helpers import get_app_path, get_dbfilename, load_icon
-from jal.db.update import JalDB
+from jal.db.db import JalDB
 from jal.db.settings import JalSettings
 from jal.net.downloader import QuoteDownloader
 from jal.db.ledger import Ledger
@@ -44,10 +44,11 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.statements = StatementLoader()
         self.backup = JalBackup(self, get_dbfilename(get_app_path()))
         self.estimator = None
+        self.price_chart = None
 
         self.actionImportSlipRU.setEnabled(dependency_present(['pyzbar', 'PIL']))
 
-        self.actionAbout = QAction(text=g_tr('MainWindow', "About"), parent=self)
+        self.actionAbout = QAction(text=self.tr("About"), parent=self)
         self.MainMenu.addAction(self.actionAbout)
 
         self.langGroup = QActionGroup(self.menuLanguage)
@@ -57,21 +58,26 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.createStatementsImportMenu()
 
         # Set icons
+        self.setWindowIcon(load_icon("jal.png"))
         self.NewOperationBtn.setIcon(load_icon("new.png"))
         self.CopyOperationBtn.setIcon(load_icon("copy.png"))
         self.DeleteOperationBtn.setIcon(load_icon("delete.png"))
 
         # Operations view context menu
         self.contextMenu = QMenu(self.OperationsTableView)
-        self.actionReconcile = QAction(load_icon("reconcile.png"), g_tr('MainWindow', "Reconcile"), self)
-        self.actionCopy = QAction(load_icon("copy.png"), g_tr('MainWindow', "Copy"), self)
-        self.actionDelete = QAction(load_icon("delete.png"), g_tr('MainWindow', "Delete"), self)
+        self.actionReconcile = QAction(load_icon("reconcile.png"), self.tr("Reconcile"), self)
+        self.actionCopy = QAction(load_icon("copy.png"), self.tr("Copy"), self)
+        self.actionDelete = QAction(load_icon("delete.png"), self.tr("Delete"), self)
         self.contextMenu.addAction(self.actionReconcile)
         self.contextMenu.addSeparator()
         self.contextMenu.addAction(self.actionCopy)
         self.contextMenu.addAction(self.actionDelete)
 
         # Customize Status bar and logs
+        self.ProgressBar = QProgressBar(self)
+        self.StatusBar.addWidget(self.ProgressBar)
+        self.ProgressBar.setVisible(False)
+        self.ledger.setProgressBar(self, self.ProgressBar)
         self.NewLogEventLbl = QLabel(self)
         self.StatusBar.addWidget(self.NewLogEventLbl)
         self.Logs.setNotificationLabel(self.NewLogEventLbl)
@@ -111,9 +117,11 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.NewOperationBtn.setMenu(self.NewOperationMenu)
 
         # Setup balance and holdings parameters
-        self.BalanceDate.setDateTime(QDateTime.currentDateTime())
+        current_time = QDateTime.currentDateTime()
+        current_time.setTimeSpec(Qt.UTC)  # We use UTC everywhere so need to force TZ info
+        self.BalanceDate.setDateTime(current_time)
         self.BalancesCurrencyCombo.setIndex(JalSettings().getValue('BaseCurrency'))
-        self.HoldingsDate.setDateTime(QDateTime.currentDateTime())
+        self.HoldingsDate.setDateTime(current_time)
         self.HoldingsCurrencyCombo.setIndex(JalSettings().getValue('BaseCurrency'))
 
         self.OperationsTabs.setCurrentIndex(TransactionType.NA)
@@ -189,10 +197,10 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         language_code = action.data()
         if language_code != self.currentLanguage:
             JalSettings().setValue('Language', JalDB().get_language_id(language_code))
-            QMessageBox().information(self, g_tr('MainWindow', "Restart required"),
-                                      g_tr('MainWindow', "Language was changed to ") +
+            QMessageBox().information(self, self.tr("Restart required"),
+                                      self.tr("Language was changed to ") +
                                       QLocale.languageToString(QLocale(language_code).language()) + "\n" +
-                                      g_tr('MainWindow', "You should restart application to apply changes\n"
+                                      self.tr("You should restart application to apply changes\n"
                                            "Application will be terminated now"),
                                       QMessageBox.Ok)
             self.close()
@@ -213,18 +221,22 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
     def showAboutWindow(self):
         about_box = QMessageBox(self)
         about_box.setAttribute(Qt.WA_DeleteOnClose)
-        about_box.setWindowTitle(g_tr('MainWindow', "About"))
-        title = g_tr('MainWindow',
-                     "<h3>JAL</h3><p>Just Another Ledger, version {version}</p>".format(version=__version__))
+        about_box.setWindowTitle(self.tr("About"))
+        title = self.tr("<h3>JAL</h3><p>Just Another Ledger, version {version}</p>".format(version=__version__))
         about_box.setText(title)
-        about = g_tr('MainWindow', "<p>More information, manuals and problem reports are at "
-                                   "<a href=https://github.com/titov-vv/jal>github home page</a></p>"
-                                   "<p>Questions, comments, help or donations:</p>"
-                                   "<p><a href=mailto:jal@gmx.ru>jal@gmx.ru</a></p>"
-                                   "<p><a href=https://t.me/jal_support>Telegram</a></p>")
+        about = self.tr("<p>More information, manuals and problem reports are at "
+                        "<a href=https://github.com/titov-vv/jal>github home page</a></p>"
+                        "<p>Questions, comments, help or donations:</p>"
+                        "<p><a href=mailto:jal@gmx.ru>jal@gmx.ru</a></p>"
+                        "<p><a href=https://t.me/jal_support>Telegram</a></p>")
         about_box.setInformativeText(about)
         about_box.show()
 
+    def showProgressBar(self, visible=False):
+        self.ProgressBar.setVisible(visible)
+        self.centralwidget.setEnabled(not visible)
+        self.MainMenu.setEnabled(not visible)
+
     @Slot()
     def OnBalanceDoubleClick(self, index):
         self.ChooseAccountBtn.account_id = index.model().getAccountId(index.row())
@@ -239,8 +251,8 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
             4: ManipulateDate.RangePreviousYear
         }
         begin, end = report_ranges[range_index]()
-        self.ReportFromDate.setDateTime(QDateTime.fromSecsSinceEpoch(begin))
-        self.ReportToDate.setDateTime(QDateTime.fromSecsSinceEpoch(end))
+        self.ReportFromDate.setDateTime(QDateTime.fromSecsSinceEpoch(begin, spec=Qt.UTC))
+        self.ReportToDate.setDateTime(QDateTime.fromSecsSinceEpoch(end, spec=Qt.UTC))
 
     @Slot()
     def onRunReport(self):
@@ -273,17 +285,22 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
     @Slot()
     def importSlip(self):
         dialog = ImportSlipDialog(self)
-        dialog.show()
+        dialog.finished.connect(self.onSlipImportFinished)
+        dialog.open()
+
+    @Slot()
+    def onSlipImportFinished(self):
+        self.ledger.rebuild()
 
     @Slot()
     def onHoldingsContextMenu(self, pos):
         index = self.HoldingsTableView.indexAt(pos)
         contextMenu = QMenu(self.HoldingsTableView)
-        actionShowChart = QAction(text=g_tr('Ledger', "Show Price Chart"), parent=self.HoldingsTableView)
+        actionShowChart = QAction(text=self.tr("Show Price Chart"), parent=self.HoldingsTableView)
         actionShowChart.triggered.connect(
             partial(self.showPriceChart, self.HoldingsTableView.viewport().mapToGlobal(pos), index))
         contextMenu.addAction(actionShowChart)
-        actionEstimateTax = QAction(text=g_tr('Ledger', "Estimate Russian Tax"), parent=self.HoldingsTableView)
+        actionEstimateTax = QAction(text=self.tr("Estimate Russian Tax"), parent=self.HoldingsTableView)
         actionEstimateTax.triggered.connect(
             partial(self.estimateRussianTax, self.HoldingsTableView.viewport().mapToGlobal(pos), index))
         contextMenu.addAction(actionEstimateTax)
@@ -323,10 +340,9 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
     def checkForUncommittedChanges(self):
         for i in range(self.OperationsTabs.count()):
             if hasattr(self.OperationsTabs.widget(i), "isCustom") and self.OperationsTabs.widget(i).modified:
-                reply = QMessageBox().warning(None,
-                                              g_tr('MainWindow', "You have unsaved changes"),
+                reply = QMessageBox().warning(None, self.tr("You have unsaved changes"),
                                               self.OperationsTabs.widget(i).name +
-                                              g_tr('MainWindow', " has uncommitted changes,\ndo you want to save it?"),
+                                              self.tr(" has uncommitted changes,\ndo you want to save it?"),
                                               QMessageBox.Yes, QMessageBox.No)
                 if reply == QMessageBox.Yes:
                     self.OperationsTabs.widget(i).saveChanges()
@@ -346,17 +362,16 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
 
     @Slot()
     def reconcileAtCurrentOperation(self):
-        timestamp_idx = self.operations_model.index(self.current_index.row(), self.operations_model.COL_TIMESTAMP)
-        timestamp = self.operations_model.data(timestamp_idx, Qt.UserRole)
-        account_idx = self.operations_model.index(self.current_index.row(), self.operations_model.COL_ACCOUNT_ID)
-        account_id = self.operations_model.data(account_idx, Qt.UserRole)
-        self.ledger.reconcile(account_id, timestamp)
+        idx = self.operations_model.index(self.current_index.row(), 0)  # we need only row to address fields by name
+        timestamp = self.operations_model.data(idx, Qt.UserRole, field="timestamp")
+        account_id = self.operations_model.data(idx, Qt.UserRole, field="account_id")
+        JalDB().reconcile_account(account_id, timestamp)
         self.operations_model.refresh()
 
     @Slot()
     def deleteOperation(self):
-        if QMessageBox().warning(None, g_tr('MainWindow', "Confirmation"),
-                                 g_tr('MainWindow', "Are you sure to delete selected transacion(s)?"),
+        if QMessageBox().warning(None, self.tr("Confirmation"),
+                                 self.tr("Are you sure to delete selected transacion(s)?"),
                                  QMessageBox.Yes, QMessageBox.No) == QMessageBox.No:
             return
         rows = []
@@ -386,21 +401,21 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
     @Slot()
     def onDataDialog(self, dlg_type):
         if dlg_type == "account_types":
-            AccountTypeListDialog().exec_()
+            AccountTypeListDialog().exec()
         elif dlg_type == "accounts":
-            AccountListDialog().exec_()
+            AccountListDialog().exec()
         elif dlg_type == "assets":
-            AssetListDialog().exec_()
+            AssetListDialog().exec()
         elif dlg_type == "agents":
-            PeerListDialog().exec_()
+            PeerListDialog().exec()
         elif dlg_type == "categories":
-            CategoryListDialog().exec_()
+            CategoryListDialog().exec()
         elif dlg_type == "tags":
-            TagsListDialog().exec_()
+            TagsListDialog().exec()
         elif dlg_type == "countries":
-            CountryListDialog().exec_()
+            CountryListDialog().exec()
         elif dlg_type == "quotes":
-            QuotesListDialog().exec_()
+            QuotesListDialog().exec()
         else:
             assert False
 
@@ -409,13 +424,13 @@ class MainWindow(QMainWindow, Ui_JAL_MainWindow):
         self.ledger.rebuild()
         for account_id in totals:
             for asset_id in totals[account_id]:
-                amount = self.ledger.get_asset_amount(timestamp, account_id, asset_id)
+                amount = JalDB().get_asset_amount(timestamp, account_id, asset_id)
                 if amount is not None:
                     if abs(totals[account_id][asset_id] - amount) <= Setup.DISP_TOLERANCE:
-                        self.ledger.reconcile(account_id, timestamp)
+                        JalDB().reconcile_account(account_id, timestamp)
                         self.balances_model.update()   # Update required to display reconciled
                     else:
                         account = JalDB().get_account_name(account_id)
                         asset = JalDB().get_asset_name(asset_id)
-                        logging.warning(g_tr('MainWindow', "Statement ending balance doesn't match: ") +
+                        logging.warning(self.tr("Statement ending balance doesn't match: ") +
                                         f"{account} / {asset} / {amount} <> {totals[account_id][asset_id]}")
