@@ -1,9 +1,8 @@
 from datetime import datetime
 from dateutil import tz
 
-from PySide2.QtCore import Qt
-from PySide2.QtWidgets import QLabel, QDateTimeEdit, QDateEdit, QLineEdit
-from jal.widgets.helpers import g_tr
+from PySide6.QtCore import Qt
+from PySide6.QtWidgets import QLabel, QDateTimeEdit, QDateEdit, QLineEdit
 from jal.widgets.abstract_operation_details import AbstractOperationDetails
 from jal.widgets.reference_selector import AccountSelector, AssetSelector
 from jal.widgets.delegates import WidgetMapperDelegateBase
@@ -36,26 +35,26 @@ class TradeWidget(AbstractOperationDetails):
         self.fee_label = QLabel(self)
         self.comment_label = QLabel(self)
 
-        self.main_label.setText(g_tr("TradeWidget", "Buy / Sell"))
-        self.date_label.setText(g_tr("TradeWidget", "Date/Time"))
-        self.settlement_label.setText(g_tr("TradeWidget", "Settlement"))
-        self.number_label.setText(g_tr("TradeWidget", "#"))
-        self.account_label.setText(g_tr("TradeWidget", "Account"))
-        self.symbol_label.setText(g_tr("TradeWidget", "Asset"))
-        self.qty_label.setText(g_tr("TradeWidget", "Qty"))
-        self.price_label.setText(g_tr("TradeWidget", "Price"))
-        self.fee_label.setText(g_tr("TradeWidget", "Fee"))
-        self.comment_label.setText(g_tr("TradeWidget", "Note"))
+        self.main_label.setText(self.tr("Buy / Sell"))
+        self.date_label.setText(self.tr("Date/Time"))
+        self.settlement_label.setText(self.tr("Settlement"))
+        self.number_label.setText(self.tr("#"))
+        self.account_label.setText(self.tr("Account"))
+        self.symbol_label.setText(self.tr("Asset"))
+        self.qty_label.setText(self.tr("Qty"))
+        self.price_label.setText(self.tr("Price"))
+        self.fee_label.setText(self.tr("Fee"))
+        self.comment_label.setText(self.tr("Note"))
 
         self.timestamp_editor = QDateTimeEdit(self)
         self.timestamp_editor.setCalendarPopup(True)
         self.timestamp_editor.setTimeSpec(Qt.UTC)
-        self.timestamp_editor.setFixedWidth(self.timestamp_editor.fontMetrics().width("00/00/0000 00:00:00") * 1.25)
+        self.timestamp_editor.setFixedWidth(self.timestamp_editor.fontMetrics().horizontalAdvance("00/00/0000 00:00:00") * 1.25)
         self.timestamp_editor.setDisplayFormat("dd/MM/yyyy hh:mm:ss")
         self.settlement_editor = QDateEdit(self)
         self.settlement_editor.setCalendarPopup(True)
         self.settlement_editor.setTimeSpec(Qt.UTC)
-        self.settlement_editor.setFixedWidth(self.settlement_editor.fontMetrics().width("00/00/0000") * 1.5)
+        self.settlement_editor.setFixedWidth(self.settlement_editor.fontMetrics().horizontalAdvance("00/00/0000") * 1.5)
         self.settlement_editor.setDisplayFormat("dd/MM/yyyy")
         self.account_widget = AccountSelector(self)
         self.asset_widget = AssetSelector(self)
