@@ -1,11 +1,11 @@
 import pytest
 import os
 from shutil import copyfile
-from PySide2.QtSql import QSqlDatabase
+from PySide6.QtSql import QSqlDatabase
 
 from constants import Setup, PredefinedCategory, PredefinedAsset
 from jal.db.helpers import init_and_check_db, LedgerInitError
-from jal.db.update import JalDB
+from jal.db.db import JalDB
 from jal.db.helpers import executeSQL, get_dbfilename
 
 
@@ -41,6 +41,14 @@ def prepare_db(project_root, tmp_path, data_path):
     os.remove(target_path)  # Clean db init script
     os.remove(get_dbfilename(str(tmp_path) + os.sep))  # Clean db file
 
+
+@pytest.fixture
+def prepare_db_ledger(prepare_db):
+    assert executeSQL("INSERT INTO agents (pid, name) VALUES (0, 'Shop')") is not None
+    assert executeSQL("INSERT INTO accounts (type_id, name, currency_id, active) "
+                      "VALUES (1, 'Wallet', 1, 1)") is not None
+
+
 @pytest.fixture
 def prepare_db_ibkr(prepare_db):
     assert executeSQL("INSERT INTO agents (pid, name) VALUES (0, 'IB')") is not None
@@ -89,5 +97,8 @@ def prepare_db_moex(prepare_db):   # Create SBER stock in database to be updated
     assert executeSQL("INSERT INTO assets (id, name, type_id, full_name, isin, src_id) "
                       "VALUES (6, 'SU26238RMFS4', :bond, '', 'RU000A1038V6', 0)",
                       [(":bond", PredefinedAsset.Bond)]) is not None
+    assert executeSQL("INSERT INTO assets (id, name, type_id, full_name, isin, src_id) "
+                      "VALUES (7, 'МКБ 1P2', :bond, '', 'RU000A1014H6', 0)",
+                      [(":bond", PredefinedAsset.Bond)]) is not None
     yield
 
